#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub READ {}
sub READLINE {}
sub GETC {}

my $Original_File = 'root/etc/e-smith/events/actions/floppy-put-image';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 43 root/etc/e-smith/events/actions/floppy-put-image

my $out = `$^X -cw $Original_File 2>&1`;
is( $?, 0, 'compiles' );
is( $out, "$Original_File syntax OK\n", 'no warnings' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 61 root/etc/e-smith/events/actions/floppy-put-image

my $testing_dir = "30e-smith-reinstall-floppy";

$ENV{ESMITH_CONFIG_DB}   = "$testing_dir/configuration";
$ENV{ESMITH_MOTD}        = "$testing_dir/motd";
$ENV{ESMITH_RAIDTAB}     = "$testing_dir/raidtab";
$ENV{ESMITH_FLOPPY_PATH} = "$testing_dir";

unlink("$testing_dir/ks.cfg");

$ENV{ESMITH_TESTING_REINSTALL_FLOPPY} = 1;    # Skip writing the floppy
is(system("$^X $Original_File"), 0, "System command returned 0");

ok( (-f "$testing_dir/ks.cfg"), "ks.cfg file created");

open(WRITTEN, "$testing_dir/ks.cfg") or die "Couldn't read ks.cfg: $!\n";
my @written = <WRITTEN>;

open(EXPECTED, "$testing_dir/expected_raid_ks.cfg") 
    or die "Couldn't read expected_raid_ks.cfg: $!\n";
my @expected = <EXPECTED>;

is_deeply(\@written, \@expected, "Written raid ks.cfg matches expected");

$ENV{ESMITH_RAIDTAB}     = "$testing_dir/no_raidtab_file";

ok(unlink("$testing_dir/ks.cfg"), "Deleted ks.cfg again");

$ENV{ESMITH_TESTING_REINSTALL_FLOPPY} = 1;    # Skip writing the floppy
is(system("$^X $Original_File"), 0, "System command returned 0");

ok( (-f "$testing_dir/ks.cfg"), "ks.cfg file created");

open(WRITTEN, "$testing_dir/ks.cfg") or die "Couldn't read ks.cfg: $!\n";
@written = <WRITTEN>;

open(EXPECTED, "$testing_dir/expected_nonraid_ks.cfg") 
    or die "Couldn't read expected_nonraid_ks.cfg: $!\n";
@expected = <EXPECTED>;

is_deeply(\@written, \@expected, "Written nonraid ks.cfg matches expected");


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

